<?php

if ( ! isset( $content_width ) )
	$content_width = 540;

function pantheon_setup() {

	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );


	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'pantheon' ) );

	/*
	 * This theme supports custom background color and image, and here
	 * we also set up the default background color.
	 */
	add_theme_support( 'custom-background', array(
		'default-color' => 'b0caff',
	) );

	// This theme uses a custom image size for featured images, displayed on "standard" posts.
	add_theme_support( 'post-thumbnails' );
	add_image_size('blogthumb', 540, 300, true);
}
add_action( 'after_setup_theme', 'pantheon_setup' );

/**
 * Enqueues scripts and styles for front-end.
 *
 */

function pantheon_scripts() {
	
	wp_enqueue_style( 'pantheon-style', get_stylesheet_uri() );
	wp_enqueue_script( 'superfish-script', get_template_directory_uri() . '/js/superfish.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'easing-script', get_template_directory_uri() . '/js/easing.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'lavalamp-script', get_template_directory_uri() . '/js/llamp.js', array( 'jquery' ), '', true );
	if(is_front_page()){
	wp_enqueue_script( 'pantheon-slideshow', get_template_directory_uri() . '/js/slideshow.js', array( 'jquery' ), '', true );
	}
	/*
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'pantheon_scripts' );
/**
 * Makes our wp_nav_menu() fallback -- wp_page_menu() -- show a home link.
 *
 */
function pantheon_page_menu_args( $args ) {
	if ( ! isset( $args['show_home'] ) )
		$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'pantheon_page_menu_args' );

/**
 * Registers our main widget area and the front page widget areas.
 *
 */
function pantheon_widgets_init() {
	
	register_sidebar( array(
		'name' => __( 'Right Sidebar', 'pantheon' ),
		'id' => 'sidebar-1',
		'description' => __( 'Appears in all posts and pages.', 'pantheon' ),
		'before_widget' => '<div id="%1$s" class="widgets">',
      	'after_widget' => '</div>',
		'before_title' => '<h2><span>',
		'after_title' => '</span></h2>',
	) );
	
}
add_action( 'widgets_init', 'pantheon_widgets_init' );

if ( ! function_exists( 'pantheon_content_nav' ) ) :
/**
 * Displays navigation to next/previous pages when applicable.
 *
 */
function pantheon_content_nav( $html_id ) {
	global $wp_query;

	$html_id = esc_attr( $html_id );

	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo $html_id; ?>" class="navigation" role="navigation">
			<h3 class="assistive-text"><?php _e( 'Post navigation', 'pantheon'); ?></h3>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts') ); ?></div>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>') ); ?></div>
		</nav><!-- #<?php echo $html_id; ?> .navigation -->
	<?php endif;
}
endif;

if ( ! function_exists( 'pantheon_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own twentytwelve_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 */
function pantheon_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'pantheon'); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'pantheon'), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<header class="comment-meta comment-author vcard">
				<?php
					echo get_avatar( $comment, 44 );
					printf( '<cite><b class="fn">%1$s</b> %2$s</cite>',
						get_comment_author_link(),
						// If current post author is also comment author, make it known visually.
						( $comment->user_id === $post->post_author ) ? '<span>' . __( 'Post author', 'pantheon') . '</span>' : ''
					);
					printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
						esc_url( get_comment_link( $comment->comment_ID ) ),
						get_comment_time( 'c' ),
						/* translators: 1: date, 2: time */
						sprintf( __( '%1$s at %2$s', 'pantheon'), get_comment_date(), get_comment_time() )
					);
				?>
			</header><!-- .comment-meta -->

			<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'pantheon'); ?></p>
			<?php endif; ?>

			<section class="comment-content comment">
				<?php comment_text(); ?>
				<?php edit_comment_link( __( 'Edit', 'pantheon'), '<p class="edit-link">', '</p>' ); ?>
			</section><!-- .comment-content -->

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'pantheon'), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

/**
 * Extends the default WordPress body class to denote:
 * 1. Using a full-width layout, when no active widgets in the sidebar
 *    or full-width template.
 * 2. Front Page template: thumbnail in use and number of sidebars for
 *    widget areas.
 * 3. White or empty background color to change the layout and spacing.
 * 4. Custom fonts enabled.
 * 5. Single or multiple authors.
 * @param array Existing class values.
 * @return array Filtered class values.
 */
function pantheon_body_class( $classes ) {
	$background_color = get_background_color();
	$background_image = get_background_image();
	return $classes;
}
add_filter( 'body_class', 'pantheon_body_class' );
add_filter( 'wp_title', 'pantheon_title', 10, 3 );
function pantheon_title( $title, $sep, $seplocation )
{
    global $page, $paged;
    // Don't affect in feeds.
    if ( is_feed() )
        return $title;
    // Add the blog name
    if ( 'right' == $seplocation )
        $title .= get_bloginfo( 'name' );
    else
        $title = get_bloginfo( 'name' ) . $title;
    // Add the blog description for the home/front page.
    $site_description = get_bloginfo( 'description', 'display' );
    if ( $site_description && ( is_home() || is_front_page() ) )
        $title .= " {$sep} {$site_description}";
    // Add a page number if necessary:
    if ( $paged >= 2 || $page >= 2 )
        $title .= " {$sep} " . sprintf( __( 'Page %s', 'dbt' ), max( $paged, $page ) );
    return $title;
}
function pantheon_custom_meta () {

	$screens = array( 'post', 'page' );

	foreach ( $screens as $screen ) {

		add_meta_box(
			'pantheon_meta',
			__( 'Feature Post in the Slider', 'pantheon'  ),
			'pantheon_meta_callback',
			$screen, 'side', 'high'
		);
	}
}
add_action( 'add_meta_boxes', 'pantheon_custom_meta' );
function pantheon_meta_callback( $post ) {
    wp_nonce_field( basename( __FILE__ ), 'pantheon_nonce' );
    $pantheon_stored_meta = get_post_meta( $post->ID );
    ?>
 
    <p>
    <span class="pantheon-row-title"><?php _e( 'Check the box to feature post in the slider', 'pantheon' )?></span>
    <div class="pantheon-row-content">
        <label for="_panthoen-slider-checkbox">
            <input type="checkbox" name="_pantheon-slider-checkbox" id="_pantheon-slider-checkbox" value="yes" <?php if ( isset ( $pantheon_stored_meta['_pantheon-slider-checkbox'] ) ) checked( $pantheon_stored_meta['_pantheon-slider-checkbox'][0], 'yes' ); ?> />
        </label>
    </div>
</p>
 
    <?php
}
function pantheon_meta_save( $post_id ) {
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'pantheon_nonce' ] ) && wp_verify_nonce( $_POST[ 'pantheon_nonce' ], basename( __FILE__ ) ) ) ? 'true' : 'false';
 
    if ( $is_autosave || $is_revision || !$is_valid_nonce ) {
        return;
    }
 
    if( isset( $_POST[ '_pantheon-slider-checkbox' ] ) ) {
    update_post_meta( $post_id, '_pantheon-slider-checkbox', 'yes' );
} else {
    delete_post_meta( $post_id, '_pantheon-slider-checkbox', '' );
}
}
add_action( 'save_post', 'pantheon_meta_save' );
if ( ! function_exists( 'pantheon_pagination' ) ) :
	function pantheon_pagination() {
		global $wp_query;

		$big = 999999999; // need an unlikely integer
		
		echo paginate_links( array(
			'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format' => '?paged=%#%',
			'current' => max( 1, get_query_var('paged') ),
			'total' => $wp_query->max_num_pages
		) );
	}
endif;